//	FileLoader.h - Derivative of FileBasedDocument, used to load and save
//				   collections of Heilan command line parameters.
//	----------------------------------------------------------------------------
//	Copyright (c) 2006-2007 Niall Moody.
//
//	This program is free software; you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation; either version 2 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program; if not, write to the Free Software
//	Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//	----------------------------------------------------------------------------

#ifndef FILELOADER_H_
#define FILELOADER_H_

class HeilanFrontEnd;

///	Derivative of FileBasedDocument, used to load and save collections of Heilan command line parameters.
class FileLoader : public FileBasedDocument
{
  public:
	///	Constructor.
	/*!
		\param parentComp Pointer to the owning Component, so we can get the
		various values.
	 */
	FileLoader(HeilanFrontEnd *parentComp);
	///	Destructor.
	~FileLoader();

	///	Returns the title of this document(?).
	const String getDocumentTitle();
	///	Called to load a document.
	const String loadDocument(const File& file);
	///	Called to save the current document.
	const String saveDocument(const File& file);
	///	Returns the last document opened.
	const File getLastDocumentOpened();
	///	Sets the last document opened.
	void setLastDocumentOpened(const File& file);

	juce_UseDebuggingNewOperator
  private:
	///	Pointer to the owning Component.
	HeilanFrontEnd *parent;

	///	The last document opened.
	static File lastDocument;
};

#endif
